'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactFormRenderer = require('@data-driven-forms/react-form-renderer');
var useFieldApi = _interopDefault(require('@data-driven-forms/react-form-renderer/use-field-api'));
var uuid = require('uuid');
var reactMagmaDom = require('react-magma-dom');
var useFormApi = _interopDefault(require('@data-driven-forms/react-form-renderer/use-form-api'));
var reactMagmaIcons = require('react-magma-icons');
var validatorTypes = _interopDefault(require('@data-driven-forms/react-form-renderer/validator-types'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded = ["input", "options", "validateOnMount", "showError", "meta"];

var GroupedCheckbox = function GroupedCheckbox(props) {
  var _useFieldApi = useFieldApi({
    name: props.name,
    type: 'checkbox',
    value: props.value
  }),
      input = _useFieldApi.input;

  return React__default.createElement(reactMagmaDom.Checkbox, Object.assign({}, props, input));
};

var CheckboxMapping = function CheckboxMapping(props) {
  var _useFieldApi2 = useFieldApi(props),
      input = _useFieldApi2.input,
      options = _useFieldApi2.options,
      validateOnMount = _useFieldApi2.validateOnMount,
      showError = _useFieldApi2.showError,
      _useFieldApi2$meta = _useFieldApi2.meta,
      error = _useFieldApi2$meta.error,
      submitFailed = _useFieldApi2$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi2, _excluded);

  var name = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || rest.errorMessage;

  if (options && options.length > 0) {
    return React__default.createElement(reactMagmaDom.FormGroup, Object.assign({
      errorMessage: errorMessage
    }, rest), options.map(function (option) {
      var _option$value;

      return React__default.createElement(GroupedCheckbox, Object.assign({
        name: name
      }, option, {
        key: (_option$value = option.value) == null ? void 0 : _option$value.toString()
      }));
    }));
  } else {
    return React__default.createElement(reactMagmaDom.Checkbox, Object.assign({}, input, {
      name: name,
      labelText: rest.labelText,
      errorMessage: errorMessage
    }, rest));
  }
};

var Checkbox = /*#__PURE__*/React__default.memo(CheckboxMapping);

var _excluded$1 = ["input", "validateOnMount", "showError", "type", "options", "meta"],
    _excluded2 = ["labelText"];

var ComboboxMapping = function ComboboxMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      options = _useFieldApi.options,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$1);

  var name = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  var innerRef = React__default.useRef(null);

  var _React$useState = React__default.useState(options.map(function (_ref) {
    var labelText = _ref.labelText,
        rest = _objectWithoutPropertiesLoose(_ref, _excluded2);

    return _extends({
      label: labelText
    }, rest);
  })),
      items = _React$useState[0],
      updateItems = _React$useState[1];

  var newItemTransform = function newItemTransform(_ref2) {
    var value = _ref2.value;
    return {
      label: value,
      value: value.toLowerCase()
    };
  };

  var onItemCreated = function onItemCreated(item) {
    updateItems([].concat(items, [item]));
    input.onChange(item.value);
  };

  if (rest.isMulti) {
    rest.onSelectedItemsChange = function (evt) {
      input.onChange(evt.selectedItems.map(function (item) {
        return item.value;
      }));
    };

    rest.selectedItems = items.filter(function (item) {
      return input.value.includes(item.value);
    });
  } else {
    rest.onSelectedItemChange = function (evt) {
      input.onChange(evt.selectedItem.value);
    };

    rest.selectedItem = items.filter(function (item) {
      return item.value === input.value;
    }).pop();
  }

  return React__default.createElement(reactMagmaDom.Combobox, Object.assign({}, input, {
    id: name,
    innerRef: innerRef,
    items: items,
    newItemTransform: newItemTransform,
    onItemCreated: onItemCreated,
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var Combobox = /*#__PURE__*/React__default.memo(ComboboxMapping);

var _excluded$2 = ["customComponent"];

var CustomMapping = function CustomMapping(props) {
  var _useFieldApi = useFieldApi(props),
      CustomComponent = _useFieldApi.customComponent,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$2);

  var _useFormApi = useFormApi(),
      getState = _useFormApi.getState;

  return React.createElement(CustomComponent, Object.assign({}, rest, {
    data: getState().values
  }));
};

var Custom = /*#__PURE__*/React.memo(CustomMapping);

var _excluded$3 = ["input", "validateOnMount", "showError", "type", "meta"];

var DatePickerMapping = function DatePickerMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$3);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.DatePicker, Object.assign({}, input, {
    id: id,
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var DatePicker = /*#__PURE__*/React__default.memo(DatePickerMapping);

var FieldArrayItem = function FieldArrayItem(_ref) {
  var fields = _ref.fields,
      fieldIndex = _ref.fieldIndex,
      name = _ref.name,
      remove = _ref.remove,
      length = _ref.length,
      minItems = _ref.minItems,
      removeLabel = _ref.removeLabel;

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var theme = React.useContext(reactMagmaDom.ThemeContext);
  var editedFields = React.useMemo(function () {
    return fields.map(function (field) {
      var computedName = field.name ? name + "." + field.name : uuid.v4();
      return _extends({}, field, {
        name: computedName,
        key: computedName,
        labelText: fieldIndex === 0 ? field.labelText : null,
        children: React.createElement(reactMagmaDom.IconButton, {
          "aria-label": removeLabel,
          icon: React.createElement(reactMagmaIcons.DeleteIcon, null),
          variant: reactMagmaDom.ButtonVariant.link,
          onClick: function onClick() {
            return remove(fieldIndex);
          },
          disabled: length <= minItems
        })
      });
    });
  }, [fields, name, fieldIndex]);
  return React.createElement("div", {
    style: {
      marginTop: theme.spaceScale.spacing04
    }
  }, editedFields.map(function (field) {
    return renderForm([field]);
  }));
};

var _excluded$4 = ["arrayValidator", "label", "description", "fields", "defaultItem", "meta", "minItems", "maxItems", "noItemsMessage", "FormControlProps"];
var FieldArray = function FieldArray(_ref) {
  var props = _extends({}, _ref);

  var _useFieldApi = useFieldApi(props),
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      formFields = _useFieldApi.fields,
      defaultItem = _useFieldApi.defaultItem,
      meta = _useFieldApi.meta,
      minItems = _useFieldApi.minItems,
      maxItems = _useFieldApi.maxItems,
      _useFieldApi$noItemsM = _useFieldApi.noItemsMessage,
      noItemsMessage = _useFieldApi$noItemsM === void 0 ? "You haven't added any items yet!" : _useFieldApi$noItemsM,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$4);

  var dirty = meta.dirty,
      submitFailed = meta.submitFailed,
      error = meta.error;
  var isError = (dirty || submitFailed) && error && typeof error === 'string';
  return React.createElement(reactFormRenderer.FieldArray, {
    key: rest.input.name,
    name: rest.input.name,
    validate: arrayValidator
  }, function (_ref2) {
    var _ref2$fields = _ref2.fields,
        map = _ref2$fields.map,
        _ref2$fields$value = _ref2$fields.value,
        value = _ref2$fields$value === void 0 ? [] : _ref2$fields$value,
        push = _ref2$fields.push,
        remove = _ref2$fields.remove;
    return React.createElement(React.Fragment, null, label && React.createElement(reactMagmaDom.Heading, {
      level: 6
    }, label), React.createElement(reactMagmaDom.Button, {
      color: reactMagmaDom.ButtonColor.primary,
      type: reactMagmaDom.ButtonType.button,
      onClick: function onClick() {
        return push(defaultItem);
      },
      disabled: value.length >= maxItems
    }, "ADD ITEM"), description && React.createElement(reactMagmaDom.Paragraph, null, description), value.length <= 0 ? React.createElement(reactMagmaDom.Paragraph, null, noItemsMessage) : map(function (name, index) {
      return React.createElement(FieldArrayItem, {
        key: name,
        fields: formFields,
        name: name,
        fieldIndex: index,
        remove: remove,
        length: value.length,
        minItems: minItems,
        removeLabel: "REMOVE"
      });
    }), isError && React.createElement(reactMagmaDom.Paragraph, null, error));
  });
};

var FormGroupMapping = function FormGroupMapping(props) {
  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var subfields = React__default.useMemo(function () {
    return props.fields.map(function (field) {
      return _extends({}, field, {
        showError: props.showError
      });
    });
  }, [props.fields, props.showError]);
  return React__default.createElement(reactMagmaDom.FormGroup, Object.assign({}, props), renderForm(subfields));
};

var FormGroup = /*#__PURE__*/React__default.memo(FormGroupMapping);

var _excluded$5 = ["type"],
    _excluded2$1 = ["input", "validateOnMount", "showError", "meta", "input"];

var InputMapping = function InputMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      _useFieldApi$input = _useFieldApi.input,
      _useFieldApi$input$ty = _useFieldApi$input.type,
      type = _useFieldApi$input$ty === void 0 ? 'text' : _useFieldApi$input$ty,
      inputRest = _objectWithoutPropertiesLoose(_useFieldApi$input, _excluded$5),
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded2$1);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.Input, Object.assign({}, inputRest, {
    type: reactMagmaDom.InputType[type] || reactMagmaDom.InputType.text,
    id: id,
    errorMessage: errorMessage
  }, rest));
};

var Input = /*#__PURE__*/React__default.memo(InputMapping);

var ModalMapping = function ModalMapping(props) {
  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var subfields = React__default.useMemo(function () {
    return props.fields.map(function (field) {
      return _extends({}, field, {
        showError: props.showError
      });
    });
  }, [props.fields, props.showError]);
  return React__default.createElement(reactMagmaDom.Modal, Object.assign({}, props), renderForm(subfields));
};

var Modal = /*#__PURE__*/React__default.memo(ModalMapping);

var _excluded$6 = ["input", "validateOnMount", "showError", "meta"];

var PasswordInputMapping = function PasswordInputMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$6);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.PasswordInput, Object.assign({}, input, {
    labelText: rest.labelText,
    id: id,
    errorMessage: errorMessage
  }, rest));
};

var PasswordInput = /*#__PURE__*/React__default.memo(PasswordInputMapping);

var _excluded$7 = ["input", "options", "validateOnMount", "showError", "meta"];

var RadioMapping = function RadioMapping(props) {
  var _useFieldApi = useFieldApi(_extends({}, props, {
    type: 'radio'
  })),
      input = _useFieldApi.input,
      options = _useFieldApi.options,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$7);

  var name = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || rest.errorMessage;
  return React__default.createElement(reactMagmaDom.RadioGroup, Object.assign({
    onChange: input.onChange,
    errorMessage: errorMessage,
    name: name
  }, rest), options.map(function (option) {
    var _option$value;

    return React__default.createElement(reactMagmaDom.Radio, Object.assign({}, option, {
      key: (_option$value = option.value) == null ? void 0 : _option$value.toString()
    }));
  }));
};

var Radio = /*#__PURE__*/React__default.memo(RadioMapping);

var _excluded$8 = ["template"];
var Spy = function Spy(props) {
  var _useFieldApi = useFieldApi(props),
      Template = _useFieldApi.template,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$8);

  return React__default.createElement(reactFormRenderer.FormSpy, Object.assign({}, rest), function (props) {
    return React__default.createElement(Template, Object.assign({}, props));
  });
};

var _excluded$9 = ["input", "validateOnMount", "showError", "options", "type", "meta"],
    _excluded2$2 = ["labelText"];

var SelectMapping = function SelectMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      options = _useFieldApi.options,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$9);

  var name = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';

  if (rest.isMulti) {
    rest.onSelectedItemsChange = function (evt) {
      input.onChange(evt.selectedItems.map(function (item) {
        return item.value;
      }));
    };
  } else {
    rest.onSelectedItemChange = function (evt) {
      input.onChange(evt.selectedItem.value);
    };
  }

  return React.createElement(reactMagmaDom.Select, Object.assign({
    id: name,
    items: options.map(function (_ref) {
      var labelText = _ref.labelText,
          rest = _objectWithoutPropertiesLoose(_ref, _excluded2$2);

      return _extends({
        label: labelText
      }, rest);
    }),
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var Select = /*#__PURE__*/React.memo(SelectMapping);

var _excluded$a = ["input", "validateOnMount", "showError", "type", "meta"];

var TextareaMapping = function TextareaMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$a);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.Textarea, Object.assign({}, input, {
    id: id,
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var Textarea = /*#__PURE__*/React__default.memo(TextareaMapping);

var _excluded$b = ["input", "validateOnMount", "showError", "type", "meta"];

var TimePickerMapping = function TimePickerMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$b);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.TimePicker, Object.assign({}, input, {
    id: id,
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var TimePicker = /*#__PURE__*/React__default.memo(TimePickerMapping);

var _excluded$c = ["input", "validateOnMount", "showError", "type", "meta"];

var ToggleMapping = function ToggleMapping(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      validateOnMount = _useFieldApi.validateOnMount,
      showError = _useFieldApi.showError,
      _useFieldApi$meta = _useFieldApi.meta,
      error = _useFieldApi$meta.error,
      submitFailed = _useFieldApi$meta.submitFailed,
      rest = _objectWithoutPropertiesLoose(_useFieldApi, _excluded$c);

  var id = input.name || uuid.v4();
  var errorMessage = (validateOnMount || submitFailed || showError) && error || '';
  return React__default.createElement(reactMagmaDom.Toggle, Object.assign({}, input, {
    id: id,
    errorMessage: errorMessage,
    labelText: rest.labelText
  }, rest));
};

var Toggle = /*#__PURE__*/React__default.memo(ToggleMapping);

var _componentMapper;

(function (componentTypes) {
  componentTypes["ALERT"] = "ALERT";
  componentTypes["BANNER"] = "BANNER";
  componentTypes["CUSTOM"] = "CUSTOM";
  componentTypes["HEADING"] = "HEADING";
  componentTypes["HYPERLINK"] = "HYPERLINK";
  componentTypes["TOAST"] = "TOAST";
  componentTypes["CHECKBOX"] = "CHECKBOX";
  componentTypes["COMBOBOX"] = "COMBOBOX";
  componentTypes["DATE_PICKER"] = "DATE_PICKER";
  componentTypes["FIELD_ARRAY"] = "FIELD_ARRAY";
  componentTypes["FORM_GROUP"] = "FORM_GROUP";
  componentTypes["INPUT"] = "INPUT";
  componentTypes["MODAL"] = "MODAL";
  componentTypes["PARAGRAPH"] = "PARAGRAPH";
  componentTypes["PASSWORD_INPUT"] = "PASSWORD_INPUT";
  componentTypes["RADIO"] = "RADIO";
  componentTypes["SPY"] = "SPY";
  componentTypes["SELECT"] = "SELECT";
  componentTypes["TEXTAREA"] = "TEXTAREA";
  componentTypes["TIME_PICKER"] = "TIME_PICKER";
  componentTypes["TOGGLE"] = "TOGGLE";
})(exports.componentTypes || (exports.componentTypes = {}));

var componentMapper = (_componentMapper = {}, _componentMapper[exports.componentTypes.ALERT] = reactMagmaDom.Alert, _componentMapper[exports.componentTypes.BANNER] = reactMagmaDom.Banner, _componentMapper[exports.componentTypes.CUSTOM] = Custom, _componentMapper[exports.componentTypes.HEADING] = reactMagmaDom.Heading, _componentMapper[exports.componentTypes.HYPERLINK] = reactMagmaDom.Hyperlink, _componentMapper[exports.componentTypes.TOAST] = reactMagmaDom.Toast, _componentMapper[exports.componentTypes.CHECKBOX] = Checkbox, _componentMapper[exports.componentTypes.COMBOBOX] = Combobox, _componentMapper[exports.componentTypes.DATE_PICKER] = DatePicker, _componentMapper[exports.componentTypes.FIELD_ARRAY] = FieldArray, _componentMapper[exports.componentTypes.FORM_GROUP] = FormGroup, _componentMapper[exports.componentTypes.INPUT] = Input, _componentMapper[exports.componentTypes.MODAL] = Modal, _componentMapper[exports.componentTypes.PARAGRAPH] = reactMagmaDom.Paragraph, _componentMapper[exports.componentTypes.PASSWORD_INPUT] = PasswordInput, _componentMapper[exports.componentTypes.RADIO] = Radio, _componentMapper[exports.componentTypes.SPY] = Spy, _componentMapper[exports.componentTypes.SELECT] = Select, _componentMapper[exports.componentTypes.TEXTAREA] = Textarea, _componentMapper[exports.componentTypes.TIME_PICKER] = TimePicker, _componentMapper[exports.componentTypes.TOGGLE] = Toggle, _componentMapper);

var BasicTemplate = function BasicTemplate(_ref) {
  var formFields = _ref.formFields;
  return React__default.createElement("div", null, formFields);
};

var FormTemplate = function FormTemplate(_ref) {
  var formFields = _ref.formFields,
      _ref$schema = _ref.schema,
      cancelLabel = _ref$schema.cancelLabel,
      submitLabel = _ref$schema.submitLabel,
      schema = _ref.schema;

  var _useFormApi = useFormApi(),
      handleSubmit = _useFormApi.handleSubmit,
      onCancel = _useFormApi.onCancel,
      getState = _useFormApi.getState;

  var _getState = getState(),
      submitting = _getState.submitting,
      pristine = _getState.pristine;

  var actions = React__default.createElement(reactMagmaDom.ButtonGroup, null, React__default.createElement(reactMagmaDom.Button, {
    disabled: pristine,
    variant: reactMagmaDom.ButtonVariant.link,
    onClick: onCancel
  }, cancelLabel || 'Cancel'), React__default.createElement(reactMagmaDom.Button, {
    disabled: submitting,
    type: reactMagmaDom.ButtonType.submit,
    color: reactMagmaDom.ButtonColor.primary
  }, submitLabel || 'Submit'));
  var actionsVisible = React__default.useMemo(function () {
    return true;
  }, []);
  return React__default.createElement(reactMagmaDom.Form, {
    onSubmit: handleSubmit,
    header: schema.title,
    description: schema.description,
    actions: actionsVisible ? actions : undefined
  }, formFields);
};

var _templateMapper;

(function (templateTypes) {
  templateTypes["BASIC"] = "BASIC";
  templateTypes["FORM"] = "FORM";
})(exports.templateTypes || (exports.templateTypes = {}));

var templateMapper = (_templateMapper = {}, _templateMapper[exports.templateTypes.BASIC] = BasicTemplate, _templateMapper[exports.templateTypes.FORM] = FormTemplate, _templateMapper);

var _excluded$d = ["schema", "customComponentMapper", "customValidatorMapper"];
var SchemaRenderer = function SchemaRenderer(_ref) {
  var schema = _ref.schema,
      _ref$customComponentM = _ref.customComponentMapper,
      customComponentMapper = _ref$customComponentM === void 0 ? componentMapper : _ref$customComponentM,
      customValidatorMapper = _ref.customValidatorMapper,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$d);

  return React__default.createElement(reactFormRenderer.FormRenderer, Object.assign({
    onCancel: function onCancel() {},
    onSubmit: function onSubmit() {}
  }, rest, {
    componentMapper: customComponentMapper,
    validatorMapper: customValidatorMapper,
    FormTemplate: templateMapper[schema.type],
    schema: schema
  }));
};

exports.validatorTypes = validatorTypes;
exports.SchemaRenderer = SchemaRenderer;
exports.componentMapper = componentMapper;
exports.templateMapper = templateMapper;
//# sourceMappingURL=schema-renderer.cjs.development.js.map
